import Image from "next/image";
import Link from "next/link";
import { useRouter } from "next/router";
import { UrlObject } from "url";

export interface NavigationItemProps {
  text: string;
  iconUrl?: string;
  href: string | UrlObject;
}

export function NavigationItem({ text, iconUrl, href }: NavigationItemProps) {
  const router = useRouter();
  const active = router.pathname === href;

  return (
    <li className={active ? "navigation-item active" : "navigation-item"}>
      <Link href={href} passHref>
        <a>
          {iconUrl && <Image src={iconUrl} width="24" height="24" alt="" />}
          <span>{text}</span>
        </a>
      </Link>
    </li>
  );
}
